"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createWebpackConfig = void 0;
const tslib_1 = require("tslib");
const case_sensitive_paths_webpack_plugin_1 = tslib_1.__importDefault(require("case-sensitive-paths-webpack-plugin"));
const fork_ts_checker_webpack_plugin_1 = tslib_1.__importDefault(require("fork-ts-checker-webpack-plugin"));
const tsconfig_paths_webpack_plugin_1 = tslib_1.__importDefault(require("tsconfig-paths-webpack-plugin"));
const webpack_node_externals_1 = tslib_1.__importDefault(require("webpack-node-externals"));
const clean_webpack_plugin_1 = require("clean-webpack-plugin");
const eslint_webpack_plugin_1 = tslib_1.__importDefault(require("eslint-webpack-plugin"));
const formatTsLoaderMessages_1 = require("./formatTsLoaderMessages");
const paths_1 = require("./paths");
const env_1 = require("../util/env");
const createWebpackConfig = (environment) => {
    const isDev = environment === 'development';
    return {
        mode: environment,
        entry: paths_1.paths.appIndexJs,
        target: 'node',
        externals: [
            webpack_node_externals_1.default(env_1.RuntimeOptions.useMonorepo
                ? {
                    modulesFromFile: true,
                }
                : undefined),
        ],
        devtool: isDev ? 'eval-cheap-source-map' : 'cheap-source-map',
        output: {
            path: isDev ? paths_1.paths.appDevBundlePath : paths_1.paths.appBuild,
            filename: isDev ? 'bundle.js' : 'bundle.prod.js',
            libraryTarget: 'commonjs',
        },
        resolve: {
            extensions: ['.ts', '.js', '.json'],
            plugins: [
                new tsconfig_paths_webpack_plugin_1.default({
                    configFile: paths_1.paths.appTsConfig,
                    silent: true,
                }),
            ],
        },
        module: {
            rules: [
                {
                    test: /\.jsx?$/,
                    include: paths_1.paths.appSrc,
                    exclude: /node_modules/,
                    loader: require.resolve('babel-loader'),
                    options: {
                        babelrc: false,
                        presets: [require.resolve('@babel/preset-env')],
                        compact: true,
                    },
                },
                {
                    test: /\.tsx?$/,
                    include: paths_1.paths.appSrc,
                    loader: require.resolve('ts-loader'),
                    options: {
                        transpileOnly: true,
                        errorFormatter: formatTsLoaderMessages_1.formatTsLoaderMessages,
                    },
                },
            ],
        },
        plugins: [
            new eslint_webpack_plugin_1.default({
                eslintPath: require.resolve('eslint'),
                extensions: ['js', 'ts', 'jsx', 'tsx'],
                formatter: 'stylish',
                emitWarning: true,
                resolvePluginsRelativeTo: __dirname,
                overrideConfigFile: paths_1.paths.appEslint,
            }),
            new fork_ts_checker_webpack_plugin_1.default({
                async: false,
                typescript: {
                    configFile: paths_1.paths.appTsConfig,
                },
                formatter: 'codeframe',
            }),
            new case_sensitive_paths_webpack_plugin_1.default(),
            new clean_webpack_plugin_1.CleanWebpackPlugin(),
        ],
        optimization: {
            nodeEnv: false,
        },
        node: {
            __dirname: false,
            __filename: false,
        },
        performance: {
            hints: false,
        },
    };
};
exports.createWebpackConfig = createWebpackConfig;
//# sourceMappingURL=createWebpackConfig.js.map