"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
process.on('unhandledRejection', (err) => {
    throw err;
});
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const child_process_1 = require("child_process");
const fs = tslib_1.__importStar(require("fs-extra"));
const os = tslib_1.__importStar(require("os"));
const path = tslib_1.__importStar(require("path"));
const yarnAvailable_1 = require("./util/yarnAvailable");
const argv = process.argv.slice(2);
const createApp = (useYarn, appName) => {
    if (!appName) {
        console.error('Please specify the directory you want to create your project:');
        console.error(`  ${chalk_1.default.cyan('typescript-node-scripts create')} ${chalk_1.default.green('<directory>')}`);
        return process.exit(1);
    }
    const appPath = path.join(process.cwd(), appName);
    console.log('Creating application ' + chalk_1.default.cyan(appName) + '\n');
    const appPackageJson = {
        name: appName,
        version: '0.1.0',
        main: 'src/index.ts',
        private: true,
        scripts: {
            start: 'typescript-node-scripts start',
            build: 'typescript-node-scripts build',
            test: 'typescript-node-scripts test',
        },
    };
    const packageDevDependencies = [
        '@types/node',
        '@types/jest',
        'typescript@~4.2.3',
        'typescript-node-scripts',
    ];
    // check if the path exists
    if (fs.existsSync(appPath)) {
        console.error();
        console.error(chalk_1.default.red('Failed to create app.'));
        console.error(chalk_1.default.red('Directory "' + appName + '" exists.'));
        console.error();
        process.exit(1);
    }
    // set up the template
    fs.copySync(path.join(__dirname, '../../template'), appPath);
    // create the package json
    fs.writeFileSync(path.join(appPath, 'package.json'), JSON.stringify(appPackageJson, null, 2) + os.EOL);
    // copy gitignore
    fs.copySync(path.join(__dirname, '../../template/gitignore'), path.join(appPath, '.gitignore'));
    fs.unlinkSync(path.join(appPath, 'gitignore'));
    // install package dependencies
    console.log('Installing ' +
        [...packageDevDependencies].map((i) => chalk_1.default.cyan(i)).join(', '));
    let cmd;
    let devDependencyArgs;
    if (useYarn) {
        cmd = 'yarnpkg';
        devDependencyArgs = ['add', ...packageDevDependencies, '--dev'];
    }
    else {
        cmd = 'npm';
        devDependencyArgs = ['install', '--save-dev', ...packageDevDependencies];
    }
    // install dev dependencies
    const devDependencyProc = child_process_1.spawnSync(cmd, devDependencyArgs, {
        stdio: 'inherit',
        cwd: appPath,
    });
    if (devDependencyProc.status !== 0) {
        console.error();
        console.error(chalk_1.default.red('Command'), chalk_1.default.redBright(`'${cmd} ${devDependencyArgs.join(' ')}'`), chalk_1.default.red('failed.'));
        console.error();
        process.exit(1);
    }
    // initialize git repo
    try {
        child_process_1.execSync('git init', {
            cwd: appPath,
            stdio: 'ignore',
        });
        child_process_1.execSync('git add -A', {
            cwd: appPath,
            stdio: 'ignore',
        });
        child_process_1.execSync('git commit -m "first commit by typescript-node-scripts"', {
            cwd: appPath,
            stdio: 'ignore',
        });
    }
    catch (e) {
        console.warn(chalk_1.default.yellow('Failed to initialize git repository. You might want to initialize it yourself.'));
    }
    const displayedCommand = useYarn ? 'yarn' : 'npm';
    console.log();
    console.log(chalk_1.default.green('Successfully created ' + appName + ' at ' + appPath));
    console.log('Inside your project directory, you can run these commands:');
    console.log();
    console.log(chalk_1.default.cyan(`  ${displayedCommand} start`));
    console.log('    Starts the development server.');
    console.log();
    console.log(chalk_1.default.cyan(`  ${displayedCommand} test`));
    console.log('    Runs the Jest test runner.');
    console.log();
    console.log(chalk_1.default.cyan(`  ${displayedCommand} build`));
    console.log('    Bundles your application into a production-ready bundle.');
    console.log();
    console.log(chalk_1.default.green('To get started right away, we recommend running: \n'));
    console.log(chalk_1.default.cyan('  cd'), appName);
    console.log(chalk_1.default.cyan(`  ${displayedCommand}`), 'start');
    console.log();
};
createApp(yarnAvailable_1.yarnAvailable(), argv[0]);
//# sourceMappingURL=create.js.map