"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createJestConfig = void 0;
const tslib_1 = require("tslib");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const fs = tslib_1.__importStar(require("fs"));
const path = tslib_1.__importStar(require("path"));
const paths_1 = require("../../lib/paths");
// eslint-disable-next-line @typescript-eslint/no-var-requires
const appTsConfig = require(paths_1.paths.appTsConfig);
/**
 * Transform paths from tsconfig.json to Jest compatible path mappings
 * Transforms
 *   "@_util/*": ["src/_util/*"]
 * into
 *   "@_util/(.*)": "<rootdir>/src/_util/$1"
 * excluding global *
 * @param {json} config
 * @returns {object} key:value path mapping for jest
 */
const transformTsPathsToJestPaths = (tsconfig) => {
    const { paths: tsconfigPaths = {}, baseUrl: tsconfigBaseUrl = '', } = tsconfig.compilerOptions;
    const resolvedBase = path.join('<rootDir>', tsconfigBaseUrl);
    return Object.keys(tsconfigPaths).reduce((acc, key) => key === '*'
        ? acc
        : Object.assign({}, acc, {
            ['^' + key.replace('*', '(.*)') + '$']: path.join(resolvedBase, tsconfigPaths[key][0].replace('*', '$1')),
        }), {});
};
const createJestConfig = (rootDir, resolve) => {
    const setupTests = fs.existsSync(paths_1.paths.testsSetup)
        ? ['<rootDir>/setupTests.ts']
        : [];
    const config = {
        collectCoverageFrom: ['src/**/*.{js,jsx,ts,tsx}', '!src/**/*.d.ts'],
        testMatch: [
            '<rootDir>/src/**/__tests__/**/*.(j|t)s?(x)',
            '<rootDir>/src/**/?(*.)(spec|test|t).(j|t)s?(x)',
        ],
        transform: {
            '^.+\\.jsx?$': resolve('lib/jest/babelPreprocessor.js'),
            '^.+\\.tsx?$': resolve('lib/jest/typescriptPreprocessor.js'),
        },
        setupFilesAfterEnv: setupTests,
        testEnvironment: 'node',
        moduleFileExtensions: ['ts', 'tsx', 'js', 'jsx'],
        globals: {
            NODE_ENV: 'test',
            'ts-jest': {
                tsconfig: paths_1.paths.appTsConfig,
            },
        },
        moduleNameMapper: transformTsPathsToJestPaths(appTsConfig),
    };
    if (rootDir) {
        ;
        config.rootDir = rootDir;
    }
    const overrides = Object.assign({}, require(paths_1.paths.appPackageJson).jest);
    const supportedOverrides = [
        'collectCoverageFrom',
        'coverageReporters',
        'coverageThreshold',
    ];
    if (overrides) {
        supportedOverrides.forEach((key) => {
            if (overrides.hasOwnProperty(key)) {
                ;
                config[key] = overrides[key];
                delete overrides[key];
            }
        });
        const leftoverOverrides = Object.keys(overrides);
        if (leftoverOverrides.length) {
            console.error(chalk_1.default.red('\n' +
                'typescript-node-scripts only supports overriding these Jest options: \n\n' +
                supportedOverrides.map((key) => '  ' + chalk_1.default.bold(key)).join('\n') +
                '\n\n' +
                'These Jest options in your package.json are not supported: \n\n' +
                leftoverOverrides.map((key) => '  ' + chalk_1.default.bold(key)).join('\n') +
                '\n\n'));
            process.exit(1);
        }
    }
    return config;
};
exports.createJestConfig = createJestConfig;
//# sourceMappingURL=createJestConfig.js.map