"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.diffFileSize = exports.getBundleSize = void 0;
const tslib_1 = require("tslib");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const filesize_1 = tslib_1.__importDefault(require("filesize"));
const fs = tslib_1.__importStar(require("fs"));
const getBundleSize = (fileName) => {
    try {
        const read = fs.statSync(fileName);
        return read.size;
    }
    catch (e) {
        return null;
    }
};
exports.getBundleSize = getBundleSize;
const diffFileSize = (sizeBeforeBuild, sizeAfterBuild) => {
    if (!sizeAfterBuild) {
        return '';
    }
    const afterBuildFormatted = filesize_1.default(sizeAfterBuild, {
        base: 10,
        output: 'object',
    });
    if (!sizeBeforeBuild) {
        return chalk_1.default.green(`${afterBuildFormatted.value} ${afterBuildFormatted.symbol}`);
    }
    const diff = filesize_1.default(sizeAfterBuild - sizeBeforeBuild, {
        base: 10,
        output: 'object',
    });
    if (diff.value === 0) {
        return `${afterBuildFormatted.value} ${afterBuildFormatted.symbol} (+0 B)`;
    }
    else if (diff.value > 0) {
        return chalk_1.default.yellow(`${afterBuildFormatted.value} ${afterBuildFormatted.symbol} (+${diff.value} ${diff.symbol})`);
    }
    else {
        return chalk_1.default.green(`${afterBuildFormatted.value} ${afterBuildFormatted.symbol} (${diff.value} ${diff.symbol})`);
    }
};
exports.diffFileSize = diffFileSize;
//# sourceMappingURL=fileSizeReporter.js.map